==> oxygen-6.1.90.tar.xz: oxygen-6.1.90/desktoptheme/oxygen/metadata.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "kde-artists@kde.org",
                "Name": "The Oxygen Project",
                "Name[ar]": "مشروع أكسجين",
                "Name[az]": "Oxygen layihəsi",
                "Name[bg]": "Екипът на Oxygen",
                "Name[ca@valencia]": "El projecte Oxygen",
                "Name[ca]": "The Oxygen Project",
                "Name[cs]": "Projekt Oxygen",
                "Name[de]": "Das Oxygen-Projekt",
                "Name[en_GB]": "The Oxygen Project",
                "Name[eo]": "La Projekto Oxygen",
                "Name[es]": "El proyecto Oxygen",
                "Name[eu]": "Oxygen proiektua",
                "Name[fr]": "Le projet « Oxygen »",
                "Name[gl]": "Proxecto Oxygen",
                "Name[he]": "מיזם חמצן",
                "Name[ia]": "Le projecto Oxigen",
                "Name[it]": "Il progetto Oxygen",
                "Name[ka]": "The Oxygen Project",
                "Name[ko]": "The Oxygen Project",
                "Name[lt]": "Oxygen projektas",
                "Name[nl]": "Het project Oxygen",
                "Name[nn]": "Oxygen-prosjektet",
                "Name[pl]": "Projekt Tlenu",
                "Name[sl]": "Projekt Oxygen",
                "Name[sv]": "Oxygen-projektet",
                "Name[tr]": "Oksijen Projesi",
                "Name[uk]": "Проєкт Oxygen",
                "Name[x-test]": "xxThe Oxygen Projectxx",
                "Name[zh_CN]": "Oxygen 轻氧项目",
                "Name[zh_TW]": "Oxygen 專案"
            }
        ],
        "Category": "",
        "Description": "Theme done in the Oxygen style",
        "Description[ar]": "سمة بواسطة نمط أوكسجين",
        "Description[az]": "Mövzu Oxygen tərzində hazırlanmışdır",
        "Description[bg]": "Тема в стил Oxygen",
        "Description[ca@valencia]": "Tema fet en l'estil Oxygen",
        "Description[ca]": "Tema fet en l'estil Oxygen",
        "Description[cs]": "Motiv ve stylu Oxygen",
        "Description[de]": "Ein Design im Oxygen-Stil",
        "Description[en_GB]": "Theme done in the Oxygen style",
        "Description[eo]": "Etoso efektivigita el la Oxygen-stilo",
        "Description[es]": "Tema creado con el estilo de Oxígeno",
        "Description[eu]": "Oxygen-en estilora egindako gaia",
        "Description[fr]": "Thème réalisé dans le style « Oxygen »",
        "Description[gl]": "Tema feito no estilo Oxygen.",
        "Description[he]": "ערכת העיצוב ",
        "Description[ia]": "Thema facite in le stilo de Oxygen",
        "Description[it]": "Tema realizzato nello stile di Oxygen",
        "Description[ka]": "Oxygen-ის სტილში შესრულებული თემა",
        "Description[ko]": "Oxygen 스타일의 기본 테마",
        "Description[lt]": "Apipavidalinimas atliktas Oxygen stiliuje",
        "Description[nl]": "Thema in Oxygen-stijl",
        "Description[nn]": "Tema laga i Oxygen-stilen",
        "Description[pl]": "Wygląd na wzór Tlenu",
        "Description[sl]": "Tema izdelana v slogu Oxygen",
        "Description[sv]": "Tema skapat med Oxygen-stilen",
        "Description[tr]": "Oksijen biçeminde yapılmış tema",
        "Description[uk]": "Тему виконано у стилі Oxygen",
        "Description[x-test]": "xxTheme done in the Oxygen stylexx",
        "Description[zh_CN]": "Oxygen 轻氧风格的主题",
        "Description[zh_TW]": "以 Oxygen 風格所做的主題",
        "EnabledByDefault": true,
        "Id": "oxygen",
        "License": "GPL",
        "Name": "Oxygen",
        "Name[ar]": "أكسجين",
        "Name[az]": "Oxygen",
        "Name[bg]": "Oxygen",
        "Name[ca@valencia]": "Oxygen",
        "Name[ca]": "Oxygen",
        "Name[cs]": "Oxygen",
        "Name[da]": "Oxygen",
        "Name[de]": "Oxygen",
        "Name[el]": "Oxygen",
        "Name[en_GB]": "Oxygen",
        "Name[eo]": "Oxygen",
        "Name[es]": "Oxígeno",
        "Name[et]": "Oxygen",
        "Name[eu]": "Oxygen",
        "Name[fi]": "Oxygen",
        "Name[fr]": "Oxygen",
        "Name[gl]": "Oxygen",
        "Name[he]": "חמצן",
        "Name[hu]": "Oxygen",
        "Name[ia]": "Oxygen",
        "Name[id]": "Oxygen",
        "Name[it]": "Oxygen",
        "Name[ka]": "Oxygen",
        "Name[ko]": "Oxygen",
        "Name[lt]": "Oxygen",
        "Name[lv]": "Oxygen",
        "Name[nb]": "Oxygen",
        "Name[nl]": "Oxygen",
        "Name[nn]": "Oxygen",
        "Name[pa]": "ਆਕਸੀਜਨ",
        "Name[pl]": "Tlen",
        "Name[pt]": "Oxygen",
        "Name[pt_BR]": "Oxygen",
        "Name[ro]": "Oxygen",
        "Name[ru]": "Oxygen",
        "Name[sk]": "Kyslík",
        "Name[sl]": "Kisik",
        "Name[sr@ijekavian]": "Кисеоник",
        "Name[sr@ijekavianlatin]": "Kiseonik",
        "Name[sr@latin]": "Kiseonik",
        "Name[sr]": "Кисеоник",
        "Name[sv]": "Oxygen",
        "Name[tg]": "Oxygen",
        "Name[tr]": "Oksijen",
        "Name[uk]": "Oxygen",
        "Name[x-test]": "xxOxygenxx",
        "Name[zh_CN]": "Oxygen 轻氧",
        "Name[zh_TW]": "Oxygen",
        "Version": "@KF6_MIN_VERSION@",
        "Website": "https://www.kde.org/"
    },
    "X-Plasma-API": "5.0"
}

==> oxygen-6.2.1.tar.xz: oxygen-6.2.1/desktoptheme/oxygen/metadata.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "kde-artists@kde.org",
                "Name": "The Oxygen Project",
                "Name[ar]": "مشروع أكسجين",
                "Name[az]": "Oxygen layihəsi",
                "Name[bg]": "Екипът на Oxygen",
                "Name[ca@valencia]": "El projecte Oxygen",
                "Name[ca]": "The Oxygen Project",
                "Name[cs]": "Projekt Oxygen",
                "Name[de]": "Das Oxygen-Projekt",
                "Name[en_GB]": "The Oxygen Project",
                "Name[eo]": "La Projekto Oxygen",
                "Name[es]": "El proyecto Oxygen",
                "Name[eu]": "Oxygen proiektua",
                "Name[fr]": "Le projet « Oxygen »",
                "Name[gl]": "Proxecto Oxygen",
                "Name[he]": "מיזם חמצן",
                "Name[hu]": "Az Oxygen projekt",
                "Name[ia]": "Le projecto Oxigen",
                "Name[it]": "Il progetto Oxygen",
                "Name[ka]": "The Oxygen Project",
                "Name[ko]": "The Oxygen Project",
                "Name[lt]": "Oxygen projektas",
                "Name[nl]": "Het project Oxygen",
                "Name[nn]": "Oxygen-prosjektet",
                "Name[pl]": "Projekt Tlenu",
                "Name[ru]": "Проект Oxygen",
                "Name[sl]": "Projekt Oxygen",
                "Name[sv]": "Oxygen-projektet",
                "Name[tr]": "Oksijen Projesi",
                "Name[uk]": "Проєкт Oxygen",
                "Name[x-test]": "xxThe Oxygen Projectxx",
                "Name[zh_CN]": "Oxygen 轻氧项目",
                "Name[zh_TW]": "Oxygen 專案"
            }
        ],
        "Category": "",
        "Description": "Theme done in the Oxygen style",
        "Description[ar]": "سمة بواسطة نمط أوكسجين",
        "Description[az]": "Mövzu Oxygen tərzində hazırlanmışdır",
        "Description[bg]": "Тема в стил Oxygen",
        "Description[ca@valencia]": "Tema fet en l'estil Oxygen",
        "Description[ca]": "Tema fet en l'estil Oxygen",
        "Description[cs]": "Motiv ve stylu Oxygen",
        "Description[de]": "Ein Design im Oxygen-Stil",
        "Description[en_GB]": "Theme done in the Oxygen style",
        "Description[eo]": "Etoso efektivigita el la Oxygen-stilo",
        "Description[es]": "Tema creado con el estilo de Oxígeno",
        "Description[eu]": "Oxygen-en estilora egindako gaia",
        "Description[fr]": "Thème réalisé dans le style « Oxygen »",
        "Description[gl]": "Tema feito no estilo Oxygen.",
        "Description[he]": "ערכת העיצוב ",
        "Description[hu]": "Az Oxygen stílusában készült téma",
        "Description[ia]": "Thema facite in le stilo de Oxygen",
        "Description[it]": "Tema realizzato nello stile di Oxygen",
        "Description[ka]": "Oxygen-ის სტილში შესრულებული თემა",
        "Description[ko]": "Oxygen 스타일의 기본 테마",
        "Description[lt]": "Apipavidalinimas atliktas Oxygen stiliuje",
        "Description[nl]": "Thema in Oxygen-stijl",
        "Description[nn]": "Tema laga i Oxygen-stilen",
        "Description[pl]": "Wygląd na wzór Tlenu",
        "Description[ru]": "Тема в стиле Oxygen",
        "Description[sl]": "Tema izdelana v slogu Oxygen",
        "Description[sv]": "Tema skapat med Oxygen-stilen",
        "Description[tr]": "Oksijen biçeminde yapılmış tema",
        "Description[uk]": "Тему виконано у стилі Oxygen",
        "Description[x-test]": "xxTheme done in the Oxygen stylexx",
        "Description[zh_CN]": "Oxygen 轻氧风格的主题",
        "Description[zh_TW]": "以 Oxygen 風格所做的主題",
        "EnabledByDefault": true,
        "Id": "oxygen",
        "License": "GPL",
        "Name": "Oxygen",
        "Name[ar]": "أكسجين",
        "Name[az]": "Oxygen",
        "Name[bg]": "Oxygen",
        "Name[ca@valencia]": "Oxygen",
        "Name[ca]": "Oxygen",
        "Name[cs]": "Oxygen",
        "Name[da]": "Oxygen",
        "Name[de]": "Oxygen",
        "Name[el]": "Oxygen",
        "Name[en_GB]": "Oxygen",
        "Name[eo]": "Oxygen",
        "Name[es]": "Oxígeno",
        "Name[et]": "Oxygen",
        "Name[eu]": "Oxygen",
        "Name[fi]": "Oxygen",
        "Name[fr]": "Oxygen",
        "Name[gl]": "Oxygen",
        "Name[he]": "חמצן",
        "Name[hu]": "Oxygen",
        "Name[ia]": "Oxygen",
        "Name[id]": "Oxygen",
        "Name[it]": "Oxygen",
        "Name[ka]": "Oxygen",
        "Name[ko]": "Oxygen",
        "Name[lt]": "Oxygen",
        "Name[lv]": "Oxygen",
        "Name[nb]": "Oxygen",
        "Name[nl]": "Oxygen",
        "Name[nn]": "Oxygen",
        "Name[pa]": "ਆਕਸੀਜਨ",
        "Name[pl]": "Tlen",
        "Name[pt]": "Oxygen",
        "Name[pt_BR]": "Oxygen",
        "Name[ro]": "Oxygen",
        "Name[ru]": "Oxygen",
        "Name[sk]": "Kyslík",
        "Name[sl]": "Kisik",
        "Name[sr@ijekavian]": "Кисеоник",
        "Name[sr@ijekavianlatin]": "Kiseonik",
        "Name[sr@latin]": "Kiseonik",
        "Name[sr]": "Кисеоник",
        "Name[sv]": "Oxygen",
        "Name[tg]": "Oxygen",
        "Name[tr]": "Oksijen",
        "Name[uk]": "Oxygen",
        "Name[x-test]": "xxOxygenxx",
        "Name[zh_CN]": "Oxygen 轻氧",
        "Name[zh_TW]": "Oxygen",
        "Version": "@KF6_MIN_VERSION@",
        "Website": "https://www.kde.org/"
    },
    "X-Plasma-API": "5.0"
}
